@@ -16,7 +16,11 @@
 // =============================================================================
 
 #include <locale.h>
-#include <curses.h>
+#if HAVE_LIBNCURSESW == 1 && NCURSESW_HAVE_SUBDIR == 1
+    #include <ncursesw/curses.h>
+#else
+    #include <curses.h>
+#endif
 #include <malloc.h>
 #include "kclog.h"
 #include "mainprog.h"
@@ -37,7 +41,6 @@ void initcurses()
     #endif
     timeout(100); //ожидание для getch() 100 милисекунд
     start_color();
-    initcolorpairs();
 }
 
 
